@@ -6,8 +6,12 @@ as.keyvalue.default <- function(x, y, ...){
   if (!missing(y)) stopifnot(is.atomic(y))
   
   # Possibly get keyvalue object by name 
-  if (length(x) == 1 && is.character(x) && 
-      is.null(names(x)) && missing(y) && exists(x, envir = as.environment("package:decoder")))
+  if (length(x) == 1    && 
+      is.character(x)   && 
+      is.null(names(x)) && 
+      missing(y)        && 
+      exists(x, envir = as.environment("package:decoder"))
+    )
     return(as.keyvalue(get(x, envir = as.environment("package:decoder"))))
   
   ## If only x supplied, x should be a named vector
