@@ -23,7 +23,8 @@ test_that("correct classes",{
   expect_is(sida,              "keyvalue")
   expect_is(icd7,              "keyvalue")
   expect_is(icd9,              "keyvalue")
-  expect_is(icd10,             "keyvalue")
+  expect_is(icd10se,           "keyvalue")
+  expect_is(icd10cm,           "keyvalue")
   expect_is(icdo,              "keyvalue")
   expect_is(icdo3,             "keyvalue")
   expect_is(snomed,            "keyvalue")
